@@ -35,7 +35,7 @@ pub mod macros {
         file_path: &std::path::Path,
         file_text: String,
         override_config: &dprint_core::configuration::ConfigKeyMap,
-      ) -> Result<String, ErrBox> {
+      ) -> anyhow::Result<String> {
         #[link(wasm_import_module = "dprint")]
         extern "C" {
           fn host_clear_bytes(length: u32);
@@ -76,7 +76,7 @@ pub mod macros {
             // error
             let length = unsafe { host_get_error_text() };
             let error_text = get_string_from_host(length);
-            Err(dprint_core::types::Error::new(error_text))
+            Err(anyhow::anyhow!("{}", error_text))
           }
           _ => unreachable!(),
         };
